%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% create_cgobjects_protocol.m; script to create stimulation protocol in
% Matlab
% Works with BrainVoyager 23.0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
bv = actxserver('BrainVoyager.BrainVoyagerScriptAccess.1')
bv.ShowLogPane; % ShowLogTab() until BV22
bv.PrintToLog('Creating a BrainVoyager stimulation protocol from Matlab...');
[FileName,PathName] = uigetfile('*.vmr', 'Please select the anatomical file ');
doc = bv.OpenDocument([PathName FileName]);
[FileName,PathName] = uigetfile('*.vtc', 'Please select the functional file ');
doc.LinkVTC(fullfile(PathName, FileName));
doc.ClearProtocol; 
doc.ProtocolExperimentName = 'Faces Houses in LVF, CVF, RVF';
doc.ProtocolResolution = 1;
doc.AddCondition('Faces_LVF');
doc.AddCondition('Houses_RVF');
doc.AddCondition('Faces_CVF');
doc.AddCondition('Houses_LVF');
doc.AddCondition('Faces_RVF');
doc.AddCondition('Houses_CVF');
paramWeight = 1.0;
doc.AddInterval('Faces_LVF', 4, 11, paramWeight);
doc.AddInterval('Houses_RVF', 20, 27, paramWeight);
doc.AddInterval('Faces_CVF', 36, 43, paramWeight);
doc.AddInterval('Houses_LVF', 52, 59, paramWeight);
doc.AddInterval('Faces_RVF', 68, 75, paramWeight);
doc.AddInterval('Houses_CVF', 84, 91, paramWeight);
doc.AddInterval('Faces_LVF', 100, 107, paramWeight);
doc.AddInterval('Houses_RVF', 116, 123, paramWeight);
doc.AddInterval('Faces_CVF', 132, 139, paramWeight);
doc.AddInterval('Houses_LVF', 148, 155, paramWeight);
doc.AddInterval('Faces_RVF', 164, 171, paramWeight);
doc.AddInterval('Houses_CVF', 180, 187, paramWeight);
doc.AddInterval('Faces_LVF', 196, 203, paramWeight);
doc.AddInterval('Houses_RVF', 212, 219, paramWeight);
doc.AddInterval('Faces_CVF', 228, 235, paramWeight);
doc.AddInterval('Houses_LVF', 244, 251, paramWeight);
doc.AddInterval('Faces_RVF', 260, 267, paramWeight);
doc.AddInterval('Houses_CVF', 276, 283, paramWeight);
doc.SetConditionColor('Faces_LVF', 200, 43, 43);
doc.SetConditionColor('Houses_RVF', 200, 200, 43);
doc.SetConditionColor('Faces_CVF', 43, 200, 43);
doc.SetConditionColor('Houses_LVF', 43, 200, 200);
doc.SetConditionColor('Faces_RVF', 43, 43, 200);
doc.SetConditionColor('Houses_CVF', 200, 43, 200);
doc.ProtocolBackgroundColorR = 0;
doc.ProtocolBackgroundColorG = 0;
doc.ProtocolBackgroundColorB = 0;
doc.ProtocolTimeCourseColorR = 255;
doc.ProtocolTimeCourseColorG = 255;
doc.ProtocolTimeCourseColorB = 255;
doc.ProtocolTimeCoursePenWidth = 2;
prtname = fullfile(PathName, 's01_sess4_blocked_vol_script.prt');
% doc.SaveStimulationProtocol(prtname);
doc.SaveProtocol(prtname);
disp(['Created protocol: ' prtname]);
bv.PrintToLog(['Created protocol: ' prtname]);
doc.Save(); % to save link to protocol permanently
