
% CreateVMRTransformToTALandMNI.m
% Created by Rainer Goebel, May 2013
% Adapted for Matlab HB, June 2013, April 2019, June 2021, Jan.2024
% Latest version used with BrainVoyager 23.0.9

% Start BrainVoyager
bv = actxserver('BrainVoyager.BrainVoyagerScriptAccess.1');
% Create the anatomical document (*.vmr)
[FileName, PathName] = uigetfile('*.dcm', 'Please select the first DICOM file (*.dcm)');
dcmname = [PathName FileName];
[pathstr, name, ext] = fileparts(dcmname);
docVMR = bv.CreateDocumentVMR( 'DICOM', dcmname, 192, false, 256, 256, 2);
docVMR.SaveAs( fullfile(pathstr, 'GSG4_MPRAGE_nondist_script.vmr'));
% Prepare: perform inhomogeneity correction and isovoxelation
docVMR = bv.ActiveDocument;
ok = docVMR.CorrectIntensityInhomogeneities();
docVMR.Close();
iihcSelection = [PathName '*_IIHC.vmr'];
iihcFiles = dir(iihcSelection);
docVMR = bv.OpenDocument(iihcFiles(1).name);
[pathstr, name, ext] = fileparts(iihcFiles(1).name);
newvmrname = fullfile(pathstr, [name '_ISO.vmr']);
ok = docVMR.AutoTransformToIsoVoxel(1, fullfile(pathstr, [name '_ISO.vmr']));
docVMR.Close();
% Transform anatomy to AC-PC, Talairach and MNI space
docVMR = bv.OpenDocument(newvmrname);
ok = docVMR.AutoACPCAndTALTransformation();
ok = docVMR.NormalizeToMNISpace();
