
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% create_vmrdocument_via_interface.m
% Script to create a BrainVoyager VMR document in Matlab with dialogs
% Works with BrainVoyager 23
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
bv = actxserver('BrainVoyager.BrainVoyagerScriptAccess.1')
h = msgbox('Please select the first file of the raw data set', 'Create VMR document');% See figure 2.2
uiwait(h);
cancel = 0;
% get first file % See figure 2.3
[filename, pathname] = uigetfile( ...
    {'*.dcm; *.IMA; *.I; *.MR; *.REC;*.hdr','Raw data files (*.dcm,*.IMA,*.I, *.MR, *.REC,*.hdr)';
    '*.dcm', 'DICOM files (*.dcm)'; ...
    '*.IMA','Siemens DICOM files (*.IMA)'; ...
    '*.I','GE I files (*.I)'; ...
    '*.MR','GE MR (*.MR)'; ...
    '*.REC','Philips files (*.REC)'; ...
    '*.hdr','Analyze (*.hdr)'}, ...
    'Please select the first file');
firstfilename = strcat(pathname, filename);
[pathstr,name,ext] = fileparts(firstfilename);
switch ext
    case '.dcm', filetype = 'DICOM'
    case '.IMA', filetype = 'SIEMENS'
    case '.I', filetype = 'GE_I'
    case '.MR', filetype = 'GE_MR'
    case '.REC', filetype = 'PHILIPS_REC'
    case '.hdr', filetype = 'ANALYZE'
    otherwise cancel = 1
end
if ~cancel
    % get parameters
    if (strcmp(ext, '.dcm') == 1) && (exist('dicominfo.m') > 0)
        dcminfo = dicominfo(firstfilename);
        bytesperpixel = (dcminfo.BitsAllocated/8);
        xres = dcminfo.Columns;
        yres = dcminfo.Rows;
    else
        prompt = {'Matrix size x:','Matrix size y:', 'Number of bytes per pixel:'}; % See figure 2.4
        dlgtitle = 'Parameters for VMR document';
        nrlines = 1;
        def = {'256','256', '2'};
        answer = inputdlg(prompt,dlgtitle,nrlines,def);
        xres = answer{1};
        yres = answer{2};
        bytesperpixel = answer{3};
    end
    button = questdlg('Are there only raw data files for a VMR document in this directory?',...% See figure 2.5
        'Create VMR script','Yes','No','Yes');
    if strcmp(button,'Yes')
        rawfileselection = [pathname ['*' ext]];
        files = dir(rawfileselection);
        sizeAr = size(files);
        nrslices = sizeAr(1);
    else
        answer = inputdlg('Please enter the number of slices'); % See figure 2.6
        nrslices = answer{1};
    end
    button = questdlg('Swap data?', 'Create VMR script','Yes','No','No'); % See figure 2.7
    if strcmp(button,'Yes'), swap = 1; else swap = 0; end;
    vmrdoc = bv.CreateDocumentVMR(filetype, firstfilename, nrslices, swap, xres, yres, bytesperpixel);
    success = vmrdoc.SaveAs(fullfile(pathname, [name '.vmr']));
end
